//
// Eternity Engine Startmap Script
//
// This code is covered under the same GPL license as the rest of the
// Eternity Engine. Please see the COPYING file or any source code file
// for more information.
//

//
// Sliding Door
//

//
// Callback function:
// Sets sectors tagged 15 through 20 instantly to their LnF, waiting 1 tic between
// moving each floor.
//
public SDoorCB()
{
   static tag = 15;
  
   // set the sectors to make no sound (should have been done in the map...)
   _SectorSpecial(2048, tag);
   
   // move the current sector down to lowest neighbor instantly
   _Floor_RaiseToLowest(tag);
   
   tag += 1;
   
   // register this function as a callback to execute again in 1 gametic, unless we 
   // just did sector 20, in which case it is time to stop
   if(tag < 21)
      _SetCallback("SDoorCB", _SWAIT_DELAY, 1);
}

//
// Script #21 -- started by walk-over trigger, starts up sliding door
//
public Script21()
{
   static bool:dooropen = false;
   
   // for some reason the trigger line is a WR line, and I can't
   // be bothered to fix it in the map, so this interlock will
   // work
   
   if(!dooropen)
   {   
      // start blazing door sound from sector tag 18
      _SectorSound("bdopn", 18);   

      // call the door callback function explicitly
      SDoorCB();
      
      dooropen = true;
   }
}

//
// Message Scripts
//

public Script22()
{
   _Printf(_MSG_CENTER, "Easy Skills\n\133Skill 1\139 - I'm Too Young To Die\n\133Skill 2\139 - Hey, Not Too Rough\a");
}

public Script30()
{
   _Printf(_MSG_CENTER, "Medium Skill\n\133Skill 3\139 - Hurt Me Plenty\a");
}

public Script31()
{
   _Printf(_MSG_CENTER, "Hard Skill\n\133Skill 4\139 - Ultra Violence\a");
}

public Script32()
{
   _Printf(_MSG_CENTER, "\133Skill 5\139 - Nightmare!\a");
}

public Script34()
{
   _Printf(_MSG_CENTER, "\133Skill 1\139 - I'm Too Young To Die\a");
}

public Script35()
{
   _Printf(_MSG_CENTER, "\133Skill 2\139 - Hey, Not Too Rough\a");
}

public Script40()
{
   _Printf(_MSG_CENTER, "Jump into the blood for\n\133Skill 3\139 - Hurt Me Plenty!\a");
}

//
// Game Starting Scripts
//

public Script41()
{
   // I'm Too Young To Die
   _StartGame(_SKILL_ITYTD, "MAP01");
}

public Script42()
{
   // Hey, Not Too Rough
   _StartGame(_SKILL_HNTR, "MAP01");
}

public Script43()
{
   // Hurt Me Plenty
   _StartGame(_SKILL_HMP, "MAP01");  
}

public Script44()
{
   // Ultra-Violence
   _StartGame(_SKILL_UV, "MAP01");
}

public Script45()
{
   // Nightmare!
   _StartGame(_SKILL_NM, "MAP01");
}

// Nostalgia message for nightmare mode.

public Script46()
{
   _Printf(_MSG_CENTER, "Are you sure? This skill level isn't\neven remotely fair!");
}

//
// Startup Message Callback
//
public StartupCB()
{
   static time = 0;
   new playername[20];
   
   // Each time the callback is started, "time" is set to the next number.
   // This makes the next message appear. On the final call, the callback
   // isn't re-registered.
   
   switch(time)
   {
   case 0:
      {
         _GetPlayerName(1, playername, false);
         _Printf(_MSG_CENTER, "Welcome to Eternity, %s", playername);
         _SetCallback("StartupCB", _SWAIT_DELAY, 100);
         time = 1;
      }
   case 1:
      {
         _Printf(_MSG_CENTER, "http://www.doomworld.com/eternity");
         _SetCallback("StartupCB", _SWAIT_DELAY, 100);
         time = 2;
      }
   case 2:
      _Printf(_MSG_CENTER, "Start map by Derek Mac Donald");
   }   
}

new fountainLocations[3][5] =
{
   //   x,    y,   z, effects,          tid
   { 1152, 1471,  88, _PFX_REDFOUNTAIN,    1 },
   {   79,  -50,  -8, _PFX_GREENFOUNTAIN,  2 },
   { -147,  -50,  -8, _PFX_GREENFOUNTAIN,  3 }
}

//
// OnInit
//
// Called when the Level Script is loaded.
//
public OnInit()
{
   // spawn some particle fountains around the map (should be done in the map...)
   new fountainType = _ThingNumForName("EEParticleFountain");
   
   for(new i = 0; i < 3; ++i)
   {
      new tid = fountainLocations[i][4];
      
      _ThingSpawn(fountainType, 
                  fountainLocations[i][0],  // x
                  fountainLocations[i][1],  // y
                  fountainLocations[i][2],  // z
                  tid);                     // tid
       
      // get proper fountain color by setting effects field
      _ThingSetProperty(tid, _THING_EFFECTS, fountainLocations[i][3]);
       
      // add no gravity flag to fountain so it won't fall through deep water
      _ThingFlagsFromStr(tid, _FLAGS_ADD, "NOGRAVITY");
   }

   // start message callback - wait a while so it doesn't show up right at the beginning
   _SetCallback("StartupCB", _SWAIT_DELAY, 18);
}

